@@ -173,6 +173,16 @@ class RequirementsBinding(RO_MappingBinding):
     def _attr_error(self, attr):
         raise AttributeError("request does not exist: '%s'" % attr)
 
+    def get_range(self, name, default=None):
+        """Returns requirement version range object"""
+        req_str = self._data.get(name)
+        if req_str:
+            return Requirement(req_str).range
+        elif default is not None:
+            return VersionRange(default)
+        else:
+            return None
+
 
 class EphemeralsBinding(RO_MappingBinding):
     """Binds a list of resolved ephemeral packages.
@@ -193,6 +203,16 @@ class EphemeralsBinding(RO_MappingBinding):
     def _attr_error(self, attr):
         raise AttributeError("ephemeral does not exist: '%s'" % attr)
 
+    def get_range(self, name, default=None):
+        """Returns ephemeral version range object"""
+        req_str = self._data.get(name)
+        if req_str:
+            return Requirement(req_str).range
+        elif default is not None:
+            return VersionRange(default)
+        else:
+            return None
+
 
 def intersects(obj, range_):
     """Test if an object intersects with the given version range.
@@ -235,6 +255,10 @@ def intersects(obj, range_):
             return False
         range2 = req.range
 
+    # eg 'if intersects(ephemerals.get_range('foo.cli', '1'), ...)'
+    elif isinstance(obj, VersionRange):
+        range2 = obj
+
     # eg 'if intersects(resolve.maya, ...)'
     elif isinstance(obj, VariantBinding):
         range2 = VersionRange(str(obj.version))
